@@ -27,7 +27,7 @@ use crate::{
 };
 use hyper::body::Bytes;
 use hyper::{
-    body::{self, Buf},
+    body,
     client::{Client as HyperClient, HttpConnector},
     header::{HeaderMap, HeaderValue, AUTHORIZATION, CONTENT_LENGTH, CONTENT_TYPE, USER_AGENT},
     Body, Response, StatusCode,
@@ -129,7 +129,7 @@ impl Debug for State {
 /// use twilight_http::Client;
 ///
 /// # #[tokio::main]
-/// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+/// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
 /// let client = Client::new("my token");
 /// # Ok(()) }
 /// ```
@@ -140,7 +140,7 @@ impl Debug for State {
 /// use std::time::Duration;
 ///
 /// # #[tokio::main]
-/// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+/// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
 /// let client = Client::builder()
 ///     .token("my token")
 ///     .timeout(Duration::from_secs(5))
@@ -252,7 +252,7 @@ impl Client {
     /// use twilight_model::id::GuildId;
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let guild_id = GuildId(1);
@@ -284,7 +284,7 @@ impl Client {
     /// use twilight_model::id::{GuildId, UserId};
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let guild_id = GuildId(100);
@@ -310,7 +310,7 @@ impl Client {
     /// use twilight_model::id::{GuildId, UserId};
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let guild_id = GuildId(100);
@@ -334,7 +334,7 @@ impl Client {
     /// # use twilight_model::id::ChannelId;
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let channel_id = ChannelId(100);
@@ -397,7 +397,7 @@ impl Client {
     /// use twilight_model::id::{ChannelId, MessageId};
     ///
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// let client = Client::new("my token");
     /// let channel_id = ChannelId(123);
     /// let message_id = MessageId(234);
@@ -446,7 +446,7 @@ impl Client {
     /// use twilight_model::id::{ChannelId, RoleId};
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     ///
     /// let channel_id = ChannelId(123);
@@ -526,7 +526,7 @@ impl Client {
     /// use twilight_model::id::GuildId;
     ///
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let after = GuildId(300);
@@ -562,7 +562,7 @@ impl Client {
     /// # use twilight_model::id::GuildId;
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let guild_id = GuildId(100);
@@ -585,7 +585,7 @@ impl Client {
     /// # use twilight_model::id::{EmojiId, GuildId};
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let guild_id = GuildId(50);
@@ -635,7 +635,7 @@ impl Client {
     /// # use twilight_http::Client;
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let info = client.gateway().await?;
@@ -649,7 +649,7 @@ impl Client {
     /// # use twilight_http::Client;
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let info = client.gateway().authed().await?;
@@ -801,7 +801,7 @@ impl Client {
     /// use twilight_model::id::{GuildId, UserId};
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let guild_id = GuildId(100);
@@ -833,7 +833,7 @@ impl Client {
     /// use twilight_model::id::GuildId;
     ///
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// let client = Client::new("my token");
     ///
     /// let guild_id = GuildId(100);
@@ -936,7 +936,7 @@ impl Client {
     /// use twilight_model::id::{GuildId, RoleId, UserId};
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let guild_id = GuildId(1);
@@ -1029,7 +1029,7 @@ impl Client {
     /// # use twilight_http::Client;
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let invite = client
@@ -1056,7 +1056,7 @@ impl Client {
     /// # use twilight_model::id::ChannelId;
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let channel_id = ChannelId(123);
@@ -1097,7 +1097,7 @@ impl Client {
     /// # use twilight_model::id::ChannelId;
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let channel_id = ChannelId(123);
@@ -1168,7 +1168,7 @@ impl Client {
     /// use twilight_model::id::{ChannelId, MessageId};
     ///
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// let client = Client::new("my token");
     /// client.update_message(ChannelId(1), MessageId(2))
     ///     .content("test update".to_owned())?
@@ -1183,7 +1183,7 @@ impl Client {
     /// # use twilight_model::id::{ChannelId, MessageId};
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// client.update_message(ChannelId(1), MessageId(2))
     ///     .content(None)?
@@ -1249,7 +1249,7 @@ impl Client {
     /// # };
     /// #
     /// # #[tokio::main]
-    /// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("my token");
     /// #
     /// let channel_id = ChannelId(123);
@@ -2305,24 +2305,14 @@ impl Client {
     pub async fn request<T: DeserializeOwned>(&self, request: Request) -> Result<T, Error> {
         let resp = self.make_request(request).await?;
 
-        let mut buf = body::aggregate(resp.into_body())
+        let bytes = body::to_bytes(resp.into_body())
             .await
             .map_err(|source| Error {
                 kind: ErrorType::ChunkingResponse,
                 source: Some(Box::new(source)),
             })?;
 
-        let mut bytes = vec![0; buf.remaining()];
-        buf.copy_to_slice(&mut bytes);
-
-        let result = crate::json::from_slice(&mut bytes);
-
-        result.map_err(|source| Error {
-            kind: ErrorType::Parsing {
-                body: bytes.clone(),
-            },
-            source: Some(Box::new(source)),
-        })
+        crate::json::parse_bytes(&bytes)
     }
 
     pub(crate) async fn request_bytes(&self, request: Request) -> Result<Bytes, Error> {
@@ -2379,22 +2369,14 @@ impl Client {
             _ => {}
         }
 
-        let mut buf = hyper::body::aggregate(resp.into_body())
+        let bytes = body::to_bytes(resp.into_body())
             .await
             .map_err(|source| Error {
                 kind: ErrorType::ChunkingResponse,
                 source: Some(Box::new(source)),
             })?;
 
-        let mut bytes = vec![0; buf.remaining()];
-        buf.copy_to_slice(&mut bytes);
-
-        let error = crate::json::from_slice::<ApiError>(&mut bytes).map_err(|source| Error {
-            kind: ErrorType::Parsing {
-                body: bytes.clone(),
-            },
-            source: Some(Box::new(source)),
-        })?;
+        let error = crate::json::parse_bytes::<ApiError>(&bytes)?;
 
         #[cfg(feature = "tracing")]
         if let ApiError::General(ref general) = error {
@@ -2407,7 +2389,7 @@ impl Client {
 
         Err(Error {
             kind: ErrorType::Response {
-                body: bytes,
+                body: bytes.to_vec(),
                 error,
                 status,
             },
