@@ -1,4 +1,9 @@
-use crate::request::prelude::*;
+use crate::{
+    client::Client,
+    error::Error,
+    request::{PendingOption, Request},
+    routing::Route,
+};
 use twilight_model::{
     guild::Ban,
     id::{GuildId, UserId},
@@ -24,7 +29,7 @@ impl<'a> GetBan<'a> {
         }
     }
 
-    fn start(&mut self) -> Result<()> {
+    fn start(&mut self) -> Result<(), Error> {
         let request = Request::from_route(Route::GetBan {
             guild_id: self.guild_id.0,
             user_id: self.user_id.0,
